
from distutils.core import setup
setup(
     name        =  "Terra_PrintAll",
     version     =  "1.2.0",
     py_modules  =  ["Terra_PrintAll"],
     author      =  "TerraJuly",
     author_email =  "caijie_hui@163.com",
     url         ="http://www.terra.com",
     description="Upgrade from 1.1.0",
     )
